import QtQuick 2.0
import Ubuntu.Components 0.1

Item {
    id: clockRoot

    property var currDate: new Date;
    property int hours: currDate.getHours()
    property int minutes: currDate.getMinutes()
    property int seconds: currDate.getUTCSeconds();

    // set this to false when app goes to background
    // hides the seconds hand since it doesnt really
    // make sense to waste cycles on updating it
    property bool isForeground: true

    function timeChanged(now) {
        hours = now.getHours()
        minutes = now.getMinutes()
        seconds = now.getUTCSeconds();
    }

    AnalogGlowEffect {
        id: glowEffect
        fillRectangle: clockOuterCircle
        /* this animation might be a bit much considering
          that the seconds hand is already moving...
          but i like it :P */
        SequentialAnimation on opacity {
            running: clockRoot.isForeground
            loops: Animation.Infinite
            NumberAnimation {
                target: glowEffect
                property: "opacity"
                to: 1.0
                duration: 500
            }
            NumberAnimation {
                target: glowEffect
                property: "opacity"
                to: 0.5
                duration: 500
            }
        }
    }

    // TODO: this might as well be an image really
    Rectangle {
        id: clockOuterCircle

        anchors.centerIn: parent
        radius: width / 2
        antialiasing: true

        width: units.gu(34)
        height: units.gu(34)

        Rectangle {
            id: innerCircle
            anchors.centerIn: clockOuterCircle
            z: 1
            width: units.gu(2)
            height: units.gu(2)
            color: "black"
            radius: width / 2
            antialiasing: true
        }

        AnalogClockHand {
            id: hourHand
            height: units.gu(10)
            // TODO: set source according to theme?
            rotationAngle: (clockRoot.hours * 30) + (clockRoot.minutes / 2)
        }

        AnalogClockHand {
            id: minuteHand
            height: units.gu(14)
            // TODO: set source according to theme?
            rotationAngle: clockRoot.minutes * 6
        }

        AnalogClockHand {
            id: secondsHand
            // TODO: set source according to theme?
            height: units.gu(16)
            width:  units.gu(1)
            rotationAngle: clockRoot.seconds * 6
        }

    }

}
