import QtQuick 2.0
import Ubuntu.Components 0.1
import "ClockUtils.js" as Utils

/*!
    \brief MainView with Tabs element.
           First Tab has a single Label and
           second Tab has a single ToolbarAction.
*/

MainView {
    id: root
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "clock"
    applicationName: "ubuntu-clock-app"

    width: units.gu(50)
    height: units.gu(75)
    
    Component.onCompleted: {
        Utils.log("MainView loaded");
    }

    property var now

    Timer {
        id: updateTimer
        objectName: "updateTimer"
        interval: 1000
        repeat: true
        running: true
        onTriggered: {
            now = new Date();
            // FIXME: only send callback to pages that need it
            /* TODO: this timer should probably be changed to fire
              every minute (max) when the app is in the background,
              or just be activated when the app is visible in the
              switcher
              */
            clockPage.onTimerUpdate(now);
            alarmPage.onTimerUpdate(now);
            timerPage.onTimerUpdate(now);
            stopwatchPage.onTimerUpdate(now);
        }
    }

    Tabs {
        id: rootTabs
        anchors.fill: parent
        
        // First tab begins here
        Tab {
            objectName: "ClockTab"
            
            title: i18n.tr("Clock")
            
            // Tab content begins here
            page: ClockPage {
                id: clockPage
            }
        }
        
        // Second tab begins here
        Tab {
            objectName: "AlarmTab"
            
            title: i18n.tr("Alarm")
            page: AlarmPage {
                id: alarmPage
            }

        }

        Tab {
            objectName: "TimerTab"

            title: i18n.tr("Timer")
            page: TimerPage {
                id: timerPage
            }
        }

        Tab {
            objectName: "StopwatchTab"

            title: i18n.tr("Stopwatch")
            page: StopwatchPage {
                id: stopwatchPage
            }
        }

    }
}
